#
# Copyright (c) 2014, Multyvac All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
"""
All modules that are pre-installed on the base Python runtimes.

Generated by running the following on an empty runtime:

import pkgutil
mods = list(pkgutil.iter_modules())
print([entry for entry in sorted([[mod, is_pkg] for _,mod,is_pkg in mods])])
"""
modules = {}
modules['ibmfunctions/action-python-v3.6'] = {'preinstalls': [['OpenSSL', True], ['PIL', True], ['__future__', False], ['_asyncio', False], ['_bisect', False], ['_blake2', False], ['_bootlocale', False], ['_bz2', False], ['_cffi_backend', False], ['_codecs_cn', False], ['_codecs_hk', False], ['_codecs_iso2022', False], ['_codecs_jp', False], ['_codecs_kr', False], ['_codecs_tw', False], ['_collections_abc', False], ['_compat_pickle', False], ['_compression', False], ['_crypt', False], ['_csv', False], ['_ctypes', False], ['_ctypes_test', False], ['_curses', False], ['_curses_panel', False], ['_datetime', False], ['_dbm', False], ['_decimal', False], ['_dummy_thread', False], ['_elementtree', False], ['_gdbm', False], ['_hashlib', False], ['_heapq', False], ['_json', False], ['_lsprof', False], ['_lzma', False], ['_markupbase', False], ['_md5', False], ['_multibytecodec', False], ['_multiprocessing', False], ['_opcode', False], ['_osx_support', False], ['_pickle', False], ['_posixsubprocess', False], ['_pydecimal', False], ['_pyio', False], ['_random', False], ['_sha1', False], ['_sha256', False], ['_sha3', False], ['_sha512', False], ['_sitebuiltins', False], ['_socket', False], ['_sqlite3', False], ['_ssl', False], ['_strptime', False], ['_struct', False], ['_sysconfigdata_m_linux_x86_64-linux-gnu', False], ['_testbuffer', False], ['_testcapi', False], ['_testimportmultiple', False], ['_testmultiphase', False], ['_threading_local', False], ['_tkinter', False], ['_weakrefset', False], ['abc', False], ['actionproxy', False], ['aifc', False], ['antigravity', False], ['argparse', False], ['array', False], ['asn1crypto', True], ['ast', False], ['asynchat', False], ['asyncio', True], ['asyncore', False], ['attr', True], ['audioop', False], ['autobahn', True], ['automat', True], ['base64', False], ['bdb', False], ['binascii', False], ['binhex', False], ['bisect', False], ['botocore', True], ['bs4', True], ['bson', True], ['bz2', False], ['cProfile', False], ['calendar', False], ['cassandra', True], ['certifi', True], ['cffi', True], ['cgi', False], ['cgitb', False], ['chardet', True], ['chunk', False], ['click', True], ['clidriver', True], ['cloudant', True], ['cmath', False], ['cmd', False], ['code', False], ['codecs', False], ['codeop', False], ['collections', True], ['colorsys', False], ['compileall', False], ['concurrent', True], ['config', False], ['configparser', False], ['constantly', True], ['contextlib', False], ['copy', False], ['copyreg', False], ['crypt', False], ['cryptography', True], ['cssselect', True], ['csv', False], ['ctypes', True], ['curses', True], ['datetime', False], ['dateutil', True], ['dbm', True], ['decimal', False], ['difflib', False], ['dis', False], ['distutils', True], ['doctest', False], ['docutils', True], ['dummy_threading', False], ['easy_install', False], ['elasticsearch', True], ['elasticsearch5', True], ['email', True], ['encodings', True], ['ensurepip', True], ['enum', False], ['exampleproj', True], ['fcntl', False], ['filecmp', False], ['fileinput', False], ['flask', True], ['fnmatch', False], ['formatter', False], ['fractions', False], ['ftplib', False], ['functools', False], ['genericpath', False], ['getopt', False], ['getpass', False], ['gettext', False], ['gevent', True], ['glob', False], ['greenlet', False], ['gridfs', True], ['grp', False], ['gzip', False], ['hamcrest', True], ['hashlib', False], ['heapq', False], ['hmac', False], ['html', True], ['http', True], ['httplib2', True], ['hyperlink', True], ['ibm_boto3', True], ['ibm_botocore', True], ['ibm_db', False], ['ibm_db_dbi', False], ['ibm_s3transfer', True], ['ibmcloudsql', True], ['idlelib', True], ['idna', True], ['imaplib', False], ['imghdr', False], ['imp', False], ['importlib', True], ['incremental', True], ['inspect', False], ['io', False], ['ipaddress', False], ['itsdangerous', True], ['jinja2', True], ['jmespath', True], ['json', True], ['kafka', True], ['keyword', False], ['lib2to3', True], ['linecache', False], ['locale', False], ['logging', True], ['lxml', True], ['lzma', False], ['macpath', False], ['macurl2path', False], ['mailbox', False], ['mailcap', False], ['markupsafe', True], ['math', False], ['mimetypes', False], ['mmap', False], ['modulefinder', False], ['multiprocessing', True], ['netrc', False], ['nis', False], ['nntplib', False], ['ntpath', False], ['nturl2path', False], ['numbers', False], ['numpy', True], ['opcode', False], ['operator', False], ['optparse', False], ['os', False], ['ossaudiodev', False], ['pandas', True], ['parsel', True], ['parser', False], ['pathlib', False], ['pdb', False], ['pickle', False], ['pickletools', False], ['pika', True], ['pip', True], ['pipes', False], ['pkg_resources', True], ['pkgutil', False], ['platform', False], ['plistlib', False], ['poplib', False], ['posixpath', False], ['pprint', False], ['profile', False], ['pstats', False], ['psycopg2', True], ['pty', False], ['py_compile', False], ['pyarrow', True], ['pyasn1', True], ['pyasn1_modules', True], ['pyclbr', False], ['pycparser', True], ['pydispatch', True], ['pydoc', False], ['pydoc_data', True], ['pyexpat', False], ['pymongo', True], ['pythonrunner', False], ['pytz', True], ['queue', False], ['queuelib', True], ['quopri', False], ['random', False], ['re', False], ['readline', False], ['redis', True], ['reprlib', False], ['requests', True], ['resource', False], ['rlcompleter', False], ['runpy', False], ['sched', False], ['scipy', True], ['scrapy', True], ['secrets', False], ['select', False], ['selectors', False], ['service_identity', True], ['setuptools', True], ['shelve', False], ['shlex', False], ['shutil', False], ['signal', False], ['simplejson', True], ['site', False], ['six', False], ['sklearn', True], ['smtpd', False], ['smtplib', False], ['sndhdr', False], ['socket', False], ['socketserver', False], ['soupsieve', True], ['spwd', False], ['sqlite3', True], ['sre_compile', False], ['sre_constants', False], ['sre_parse', False], ['ssl', False], ['stat', False], ['statistics', False], ['string', False], ['stringprep', False], ['struct', False], ['subprocess', False], ['sunau', False], ['symbol', False], ['symtable', False], ['sysconfig', False], ['syslog', False], ['tabnanny', False], ['tarfile', False], ['telnetlib', False], ['tempfile', False], ['termios', False], ['testfunctions', False], ['tests', True], ['textwrap', False], ['this', False], ['threading', False], ['timeit', False], ['tkinter', True], ['token', False], ['tokenize', False], ['tornado', True], ['trace', False], ['traceback', False], ['tracemalloc', False], ['tty', False], ['turtle', False], ['turtledemo', True], ['twisted', True], ['txaio', True], ['types', False], ['typing', False], ['unicodedata', False], ['unittest', True], ['urllib', True], ['urllib3', True], ['uu', False], ['uuid', False], ['venv', True], ['virtualenv', False], ['virtualenv_support', True], ['w3lib', True], ['warnings', False], ['watson_developer_cloud', True], ['wave', False], ['weakref', False], ['webbrowser', False], ['werkzeug', True], ['wheel', True], ['wsgiref', True], ['xdrlib', False], ['xml', True], ['xmlrpc', True], ['xxlimited', False], ['zipapp', False], ['zipfile', False], ['zlib', False]], 'python_ver': '3.6'}
